==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/library/libraryfactory.h <==
/***************************************************************************
 *   Copyright (C) 2020-2022 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef LIBRARYFACTORY_H
#define LIBRARYFACTORY_H

#include <QObject>
#include <QDialog>
#include <QPointer>
#include <qmmpui/general.h>
#include <qmmpui/generalfactory.h>

class LibraryWidget;
class Library;

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/
class LibraryFactory : public QObject, public GeneralFactory
{
Q_OBJECT
Q_PLUGIN_METADATA(IID "org.qmmp.qmmp.GeneralFactoryInterface.1.0")
Q_INTERFACES(GeneralFactory)
public:
    GeneralProperties properties() const override;
    QObject *create(QObject *parent) override;
    QWidget *createWidget(int id, QWidget *parent) override;
    QDialog *createConfigDialog(QWidget *parent) override;
    void showAbout(QWidget *parent) override;
    QString translation() const override;

private:
    enum WidgetType
    {
        LIBRARY_WIDGET = 0
    };

    QPointer<LibraryWidget> m_libraryWidget;
    QPointer<Library> m_library;
};

#endif // LIBRARYFACTORY_H

==> qmmp_2.2.2.orig.tar.bz2: qmmp-2.2.2/src/plugins/General/library/libraryfactory.h <==
/***************************************************************************
 *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef LIBRARYFACTORY_H
#define LIBRARYFACTORY_H

#include <QObject>
#include <QDialog>
#include <QPointer>
#include <qmmpui/general.h>
#include <qmmpui/generalfactory.h>

class LibraryWidget;
class Library;

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/
class LibraryFactory : public QObject, public GeneralFactory
{
Q_OBJECT
Q_PLUGIN_METADATA(IID "org.qmmp.qmmp.GeneralFactoryInterface.1.0")
Q_INTERFACES(GeneralFactory)
public:
    GeneralProperties properties() const override;
    QObject *create(QObject *parent) override;
    QWidget *createWidget(int id, QWidget *parent) override;
    QDialog *createSettings(QWidget *parent) override;
    void showAbout(QWidget *parent) override;
    QString translation() const override;

private:
    enum WidgetType
    {
        LIBRARY_WIDGET = 0
    };

    QPointer<LibraryWidget> m_libraryWidget;
    QPointer<Library> m_library;
};

#endif // LIBRARYFACTORY_H
